@@ -34,7 +34,7 @@ def get_global(key: Optional[str] = None) -> Union[str, Dict[str, Any]]:
     if _global_values is None:
         _global_values = {}
         _global_values["hostname"] = socket.gethostname()
-        _global_values["memory"] = round(psutil.virtual_memory().available / (1024 ** 3), 3)
+        _global_values["memory"] = round(psutil.virtual_memory().available / (1024**3), 3)
         _global_values["username"] = getpass.getuser()
 
         # Work through VMs and logical cores.
@@ -53,7 +53,7 @@ def get_global(key: Optional[str] = None) -> Union[str, Dict[str, Any]]:
             _global_values["cpu_brand"] = _global_values["cpuinfo"]["brand_raw"]
         except KeyError:
             # Remove this if py-cpuinfo is pinned to >=6.0.0
-            _global_values["cpu_brand"] = _global_values["cpuinfo"]["brand"]
+            _global_values["cpu_brand"] = _global_values["cpuinfo"].get("brand", "(unknown)")
 
     if key is None:
         return _global_values.copy()
